@@ -19,19 +19,33 @@ LT3
 LT4
 LT5
 
-mx = ahmd$mx
-LTs = LifeTable(x, mx = ahmd$mx)
-LTs
-expect_warning(LifeTable(x, mx = mx))
+mx1 = ahmd$mx
+LT10 = LifeTable(x, mx = mx1)
+LT10
+expect_warning(LifeTable(x, mx = mx1))
 
 
 # Example 2 --- Abridge life table ------------
-x  = c(0, 1, seq(5, 110, by = 5))
-mx = c(.053, .005, .001, .0012, .0018, .002, .003, .004,
+x2  = c(0, 1, seq(5, 110, by = 5))
+mx2 = c(.053, .005, .001, .0012, .0018, .002, .003, .004,
        .004, .005, .006, .0093, .0129, .019, .031, .049,
        .084, .129, .180, .2354, .3085, .390, .478, .551)
-LT6 = LifeTable(x, mx = mx, sex = "female")
+LT6 = LifeTable(x2, mx = mx2, sex = "female")
+LT7 = LifeTable(x2, qx = LT6$lt$qx, sex = NULL)
+LT8 = LifeTable(x2, lx = LT6$lt$lx, sex = "male")
+LT9 = LifeTable(x2, dx = LT6$lt$dx, sex = "total")
+
 LT6
+LT7
+LT8
+LT9
+
+
+x3 = c(0, 1, 2, 3, 4, 5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 60, 65, 70)
+dx = c(11728, 1998, 2190, 1336, 637, 1927, 420, 453, 475, 905, 1168, 
+       2123, 2395, 3764, 5182, 6555, 8652, 10687, 37405)
+LT11 <- LifeTable(x = x3, dx = dx)
+
 
 # TESTS ----------------------------------------------
 
@@ -47,12 +61,7 @@ foo.test.lt <- function(X) {
   })
 }
 
-foo.test.lt(LT1)
-foo.test.lt(LT2)
-foo.test.lt(LT3)
-foo.test.lt(LT4)
-foo.test.lt(LT5)
-foo.test.lt(LTs)
+for (j in 1:11) foo.test.lt(X = get(paste0("LT",j)))
 
 test_that("Identical LTs", {
   expect_identical(round(LT1$lt$ex,2), round(LT2$lt$ex, 2))
